package net.jx.servlet;
import java.util.Date;
import java.text.*;
import javax.servlet.ServletException;

public class Validator {
    private String errorPage;
    private ValidationException validationEx;

    public Validator(String errorPage) {
        this.errorPage = errorPage;
    }

    private ValidationException getValidationException() {
        if (null == validationEx)
            validationEx = new ValidationException(
                "Error validating submission", errorPage);
        return validationEx;
    }

    //check for null/empty string
    public Object mandatory(String field, String name) {
        if (null == field || field.length() == 0)
            getValidationException()
                .addMessage("Mandatory field", name);
        return field;
    }

    public Date validateDate(String field, String name) {
        if (field == null || field.length() == 0) return null;
        String pattern = "MM-dd-yyyy";
        SimpleDateFormat dateFormatter = new SimpleDateFormat(pattern);
        try {
            return dateFormatter.parse(field);
        } catch (ParseException parseEx) {
            getValidationException()
                .addMessage("Wrong date: " + pattern, name);
            return null;
        }
    }

    public Double validateCurrency(String field, String name) {
        if (field == null || field.length() == 0) return null;
        try {
            double value = Double.parseDouble(field);
            return new Double(value);
        } catch (NumberFormatException nfEx) {
            getValidationException()
                .addMessage("Wrong numeric format", name);
            return null;
        }
    }

    public void validate() throws ValidationException {
        if (validationEx != null)
            validationEx.raise();
    }
}